@@ -538,23 +538,25 @@ init_render_state(int msaa)
 
     buffer_desc.usage = SDL_GPU_BUFFERUSAGE_VERTEX;
     buffer_desc.size = sizeof(vertex_data);
-    buffer_desc.props = 0;
+    buffer_desc.props = SDL_CreateProperties();
+    SDL_SetStringProperty(buffer_desc.props, SDL_PROP_GPU_BUFFER_CREATE_NAME_STRING, "космонавт");
     render_state.buf_vertex = SDL_CreateGPUBuffer(
         gpu_device,
         &buffer_desc
     );
     CHECK_CREATE(render_state.buf_vertex, "Static vertex buffer")
-
-    SDL_SetGPUBufferName(gpu_device, render_state.buf_vertex, "космонавт");
+    SDL_DestroyProperties(buffer_desc.props);
 
     transfer_buffer_desc.usage = SDL_GPU_TRANSFERBUFFERUSAGE_UPLOAD;
     transfer_buffer_desc.size = sizeof(vertex_data);
-    transfer_buffer_desc.props = 0;
+    transfer_buffer_desc.props = SDL_CreateProperties();
+    SDL_SetStringProperty(transfer_buffer_desc.props, SDL_PROP_GPU_TRANSFERBUFFER_CREATE_NAME_STRING, "Transfer Buffer");
     buf_transfer = SDL_CreateGPUTransferBuffer(
         gpu_device,
         &transfer_buffer_desc
     );
     CHECK_CREATE(buf_transfer, "Vertex transfer buffer")
+    SDL_DestroyProperties(transfer_buffer_desc.props);
 
     /* We just need to upload the static data once. */
     map = SDL_MapGPUTransferBuffer(gpu_device, buf_transfer, false);
